@@ -22,12 +22,19 @@
 
 #include <glade/glade.h>
 #include "totem-remote.h"
+#include "scrsaver.h"
 #include "egg-recent-model.h"
 #include "egg-recent-view-gtk.h"
-#include "gtk-playlist.h"
+#include "totem-playlist.h"
 #include "bacon-message-connection.h"
 #include "bacon-video-widget.h"
 
+typedef enum {
+	TOTEM_CONTROLS_VISIBLE,
+	TOTEM_CONTROLS_HIDDEN,
+	TOTEM_CONTROLS_FULLSCREEN
+} ControlsVisibility;
+
 struct Totem {
 	/* Control window */
 	GladeXML *xml;
@@ -65,6 +72,9 @@ struct Totem {
 	GtkWidget *buffer_dialog;
 	GtkWidget *buffer_label;
 
+	/* controls management */
+	ControlsVisibility controls_visibility;
+
 	/* control fullscreen Popup */
 	GtkWidget *control_popup;
 	GtkWidget *fs_seek;
@@ -77,13 +87,15 @@ struct Totem {
 	gboolean popup_in_progress;
 	GdkRectangle fullscreen_rect;
 
+	ScreenSaver *scr;
+
 	/* recent file stuff */
 	EggRecentModel *recent_model;
 	EggRecentViewGtk *recent_view;
 
 	/* other */
 	char *mrl;
-	GtkPlaylist *playlist;
+	TotemPlaylist *playlist;
 	GConfClient *gc;
 	TotemRemote *remote;
 	BaconMessageConnection *conn;
